#############################################################################################
#Stable Isotope Trajectory Analysis (SITA): 
# A new approach to quantify and visualize dynamics in stable isotope studies
#  Sturbois A., Cucherousset J., De Cáceres M., Desroy N.,Riera P., Carpentier A.
#  Quillien N., Grall J., Espinasse B., Cherel Y., Schaal G.

#CODES TO CALCULATE SITA METRICS and to COMPUTE FIGURES 2 to 11 of the 6 ECOLOGICAL APPLICATIONS
#NOTE that some post treatment have been made on Adoble Illustrator for refining the ms figures
############################################################################################
############################################################################################
#Installing the package 'ecotraj' [De Cáceres (2019), Sturbois et al. (2021)]
# available at https://emf-creaf.github.io/ecotraj/index.html
############################################################################################
#Loading libraries
library(factoextra)
library(FactoMineR)
library(reshape)
library(gridExtra) 
library(ecotraj)
library(rgdal)
############################################################################################
############################################################################################
#ECOLOGICAL APPLICATION 1:Spatial and temporal resource partitioning in fur seals
#subset of a data sets from :Kernaléguen, L., Arnould, J.P.Y., Guinet, C., Cherel, Y., 2015. 
# Determinants of individual foraging specialization inlarge marine vertebrates, 
# the Antarctic and subantarctic fur seals. Journal of Animal Ecology 1081–1091.

#load the data set
load(file = "furseals.Rdata")
data<-furseals

#############################################
#Metrics calculations
Net_changes<-trajectoryLengths2D(data[,7:8],data$ID_SITA,data$Time, relativeToInitial=TRUE) 
Segment_lengths<-trajectoryLengths2D(data[,7:8],data$ID_SITA,data$Time, relativeToInitial=FALSE) 
Angles<-trajectoryAngles2D(data[,7:8],data$ID_SITA,data$Time, betweenSegments=FALSE)

#############################################
#Trajectory clusters
D=dist(data[,7:8])
Ds<-trajectoryDistances(D, data$ID_SITA, surveys = NULL, distance.type = "DSPD",
                        symmetrization = "mean", add = TRUE, verbose = FALSE)

Hst=2
colstd<-c("black","yellow","green","blue","grey","red")
cols<-c("red","blue","black","grey","green","yellow")
pt<-c(16,16,16,16)
x11(15,9)
par(mar = c(15, 4, 1, 1))
hsxy <- hclust(Ds, "ward.D2")
plot(hsxy,hang = -1, main="distance Fur Seals", cex=.6)
x<-rect.hclust (hsxy, h=Hst,
                border = colstd)

x
grp <- cutree(hsxy, h=Hst)
table(grp, cutree(hsxy, h=Hst))

#############################################################################
#############################################################################
#############################################################################
#FIGURES
#vector species*gender groups
group<-c()
for (i in 1:1410){
  group[i]<-c(ifelse(furseals[i,3]=="Gazella" & furseals[i,4]=="Male","Males Gazella",
                     ifelse(furseals[i,3]=="Gazella" & furseals[i,4]=="Female","Females Gazella",
                            ifelse(furseals[i,3]=="Tropicalis" & furseals[i,4]=="Male","Males Tropicalis",
                                   ifelse(furseals[i,3]=="Tropicalis" & furseals[i,4]=="Female","Females Tropicalis","ERROR")))))
}
data$group<-group
data$grp<-as.factor(grp)

########
#FIGURE2
########
p<-ggplot(data=data,aes(x=d13C,y=d15N,color=grp,shape=Place))+
  geom_point()+
  #scale_color_manual(values = cols)+  
  geom_path(aes(x=d13C,y=d15N,group=ID_SITA,color=grp),arrow = arrow(length = unit(0.10, "cm")))+
  xlab(expression("Whisker "*delta^13*"C (‰)"))+
  ylab(expression("Whisker "*delta^15*"N (‰)"))+
  facet_wrap(~group) +
  theme_classic()+
  x11()
p


########
#FIGURE3
########
NC<-Net_changes[,-30]
NC$grp<-grp
NC$ID<-as.numeric(rownames(NC))
colnames(NC)<-c(2:30,"grp","ID")
NCline<-as.data.frame(melt(NC,id=c("ID","grp")))
colnames(NCline)<-c("ID","Clusters","Time_from_present","Net_changes")
NCline[,3]<-as.numeric(NCline[,3])
NCline[,2]<-as.factor(NCline[,2])
NCline<-NCline[order(NCline[3],decreasing=F), ]
NCline$group<-c(data[1:47,9])

p<-ggplot(data=NCline,aes(x=Time_from_present,y=Net_changes,color=Clusters))+
  geom_path(aes(x=Time_from_present,y=Net_changes,group=ID, color=Clusters),arrow = arrow(length = unit(0.10, "cm")))+
  facet_wrap(~group)+
  xlab(expression("Time from present"))+
  ylab(expression("Net changes (Euclidean distance)"))+
  theme_classic()
x11()
p

###############################################################
###############################################################
library(plyr)
library(dplyr)
library(ggplot2)

Angl<-Angles
colnames(Angl)<-2:30
Angl$ID<-as.numeric(rownames(Angl))
Angl$grp<-as.factor(grp)
Angl$group<-data[1:47,9]
Angline<-as.data.frame(melt(Angl,id=c("ID","grp","group")))
colnames(Angline)<-c("ID","Clusters","Group","Time_from_present","Direction")
Angline$Direction<-as.numeric(Angline$Direction)


# range 15°
deg <- 15
# vector for range of direction of differents bars
dir.breaks <- seq(0-(deg/2), 360+(deg/2), deg)
dir.binned <- cut(Angline$Direction,
                  breaks = dir.breaks,
                  ordered_result = TRUE)
# direction labels
dir.labels <- as.character(c(seq(0, 360-deg, by = deg), 0))
levels(dir.binned) <- dir.labels

# angles distribution in each range of direction
Angline$dir.binned <- dir.binned

# sort angles
df_sorted<-as.data.frame(table(Angline$dir.binned, Angline$Clusters))
colnames(df_sorted)<-c("dir.binned","Clusters","nb")

df_cumsum <- ddply(df_sorted, "dir.binned",
                   transform, label_ypos=cumsum(nb))

########
#FIGURE4
########
x11()
ggplot(data=df_cumsum, aes(x=dir.binned, y=nb, fill=Clusters)) +
  geom_bar(stat="identity")+
  #scale_fill_brewer(palette="Paired")+
  scale_y_continuous(limits = c(0,110), expand = c(0, 0), 
                     breaks = c(0,25,50,75,110), 
                     labels = c(0,25,50,75,110)) +
  labs(x = 'Trajectory segment directions within fur seal clusters', y = 'number of trajectory segments') +
  #geom_point(aes(y=y_dist, color=distcum), size=1.3) + scale_color_gradient(low = "white", high = "black")+
  coord_polar(start = -(deg/2)*(pi/180)) +
  theme_minimal()

############################################################################################
############################################################################################

#ECOLOGICAL APPLICATION 2: Ontogenic SI trajectories of juvenile fishes
#data sets from :Cucherousset, J., Paillisson, J.-M., Roussel, J.-M., 2013. 
# Natal departure timing from spatially varying environments is dependent 
# of individual ontogenetic status. Naturwissenschaften 100, 761–768.

#load the data set
load(file = "Pike.Rdata")
data<-Pike

#############################################
#Metrics calculations
Net_changes<-trajectoryLengths2D(data[,8:9],data$ID,data$Time, relativeToInitial=TRUE) 
colnames(Net_changes)<-c("Net_changes", "Trajectory")
data$Net_Changes<-Net_changes$Net_changes
Angles<-trajectoryAngles2D(data[,8:9],data$ID,data$Time, betweenSegments=FALSE)
colnames(Angles)<-c("Angles")
#Trajectory cluster
D=dist(data[,8:9])
Ds<-trajectoryDistances(D,data$ID, surveys = NULL, distance.type = "DSPD",
                        symmetrization = "mean", add = TRUE, verbose = FALSE)

Hst=3
colstd<-c("black","yellow","green","blue","grey","red")
cols<-c("red","blue","black","grey","green","yellow")
pt<-c(16,16,16,16)
eti<-"inter"#groupe station
x11(15,9)
par(mar = c(15, 4, 1, 1))
hsxy <- hclust(Ds, "ward.D2")
hsxy$height
plot(hsxy,hang = -1, main="distance Pike", cex=.6)
x<-rect.hclust (hsxy, h=Hst,
                border = colstd)

x
grp <- cutree(hsxy, h=Hst)
table(grp, cutree(hsxy, h=Hst))

data$Cluster<-grp

########
#FIGURE5
########
Pike1<-data[data$Time %in% 1,]
Pike1<-Pike1[order(Pike1$ID, decreasing=FALSE),]
Pike1$Net_changes<-0
Pike2<-data[data$Time %in% 2,]
Pike2<-Pike2[order(Pike2$ID, decreasing=FALSE),]
Pike2$Net_changes<-Net_changes$Net_changes
data<-as.data.frame(rbind(Pike1,Pike2))
data$Angles<-Angles$Angles
  
p<-ggplot(data=data,aes(x=d13C,y=d15N,shape=Trophic_status_initial))+
  geom_point(aes(size=Net_changes))+
  geom_path(aes(x=d13C,y=d15N,group=ID,color=factor(Cluster)),arrow = arrow(length = unit(0.30, "cm")))+
  geom_hline(yintercept=10, linetype="dashed", color = "black")+
  xlab(expression(delta^13*"C")) +
  ylab(expression(delta^15*"N"))
  
X11()  
p+ theme_minimal()+
  theme(axis.text = element_text(size = 12))+
  theme(axis.title = element_text(size = 14))
X11()
p+ theme_minimal()+
  theme(axis.text = element_text(size = 12))+
  theme(axis.title = element_text(size = 14))+
  theme(legend.position = "none")

#d13C density
gg_dist_d13C = ggplot(data, aes(d13C, fill=TimeL)) + geom_density(alpha=.5) 
#gg_dist_d13C = gg_dist_d13C + ylab(expression(delta^13*"C"*" density"))
gg_dist_d13C = gg_dist_d13C + theme(axis.title.y=element_blank(),
                                    axis.text=element_blank(),
                                    axis.line=element_blank(),
                                    axis.ticks=element_blank(),
                                    panel.grid.major = element_blank(),
                                    panel.grid.minor = element_blank(),
                                    panel.background =element_blank())
gg_dist_d13C = gg_dist_d13C + theme(legend.position = "none")
x11()
gg_dist_d13C+ scale_x_continuous(limits = c(-33, -25))+scale_y_continuous(limits = c(0, 1))

#d15N density
gg_dist_d15N = ggplot(data, aes(d15N, fill=TimeL)) + geom_density(alpha=.5) 
#gg_dist_d15N = gg_dist_d15N + ylab(expression(delta^15*"N"*" density"))
gg_dist_d15N =gg_dist_d15N 
gg_dist_d15N =gg_dist_d15N + coord_flip()
gg_dist_d15N =gg_dist_d15N + theme(axis.title.y=element_blank(),
                                   axis.text=element_blank(),
                                   axis.line=element_blank(),
                                   axis.ticks=element_blank(),
                                   panel.grid.major = element_blank(),
                                   panel.grid.minor = element_blank(),
                                   panel.background =element_blank())
gg_dist_d15N =gg_dist_d15N +theme(legend.position = "none")
x11()
gg_dist_d15N + scale_x_continuous(limits = c(7, 14))+scale_y_continuous(limits = c(0, 1))

#################################################################################################
#ECOLOGICAL APPLICATION 3: Trophic consequences of experimental warming on lizards
#data sets from :Bestion, E., Soriano-Redondo, A., Cucherousset, J., Jacob, S., White, J., Zinger, L., Fourtune, L., Di Gesu, L., Teyssier, A., Cote, J., 2019.
# Altered trophic interactions in warming climates: consequences for predator diet breadth and fitness. 
# Proc. R. Soc. B. 286, 20192227.

#load the data set
load(file = "Lizard.Rdata")
data<-Lizard

#############################################
# metrics calculation
Net_Changes<-as.data.frame(trajectoryLengths2D(data[,5:6],data$SITA_IDtype,data$SITA_IDfactor, relativeToInitial=TRUE)) 
Angles<-trajectoryAngles2D(data[,5:6],data$SITA_IDtype,data$SITA_IDfactor,betweenSegments = FALSE)


df<-as.data.frame(cbind(Net_Changes,Angles))
df$Age_Gender<-c(rep("Adult female",5),rep("Adult male",5),rep("Juvenile female",5),rep("Juvenile male",5))
data<-data[order(data$Age_Gender, decreasing=FALSE),]
df<-df[order(df$Age_Gender, decreasing=FALSE),]
data$Net_change<-c(rep(0,5),df[1:5,1],rep(0,5),df[6:10,1],rep(0,5),df[11:15,1],rep(0,5),df[16:20,1])

########
#FIGURE6
########
df<-df[,c(1,3:4)]
colnames(df)<-c("Net_change","Angle","Age_Gender")
df$Block<-c("A","B","C","D","E")

x11()
ggplot(data=df, aes(x=Angle, y=Net_change, fill=Block)) +
  geom_bar(stat="identity",width=6)+
  #geom_text(aes(label = Num), vjust = -0.5, hjust=0.7, size=2.5)+
  scale_x_continuous(limits=c(0,360),breaks = c(0,90,180,270), labels=c(expression("+"*delta^15*"N"),expression("+"*delta^13*"C"),
                                                                        expression("-"*delta^15*"N"),expression("-"*delta^13*"C")))+
  scale_y_continuous(limits = c(0,2), expand = c(0, 0), 
                     breaks = c(0,0.5,1,1.5,2), 
                     labels = c(0,0.5,1,1.5,2)) +
  labs(x = 'Direction of trophic trajectories', y = 'distance') +
  coord_polar(start = 0) +
  facet_wrap(~Age_Gender)+
  theme_minimal()

#################################################################################################
#ECOLOGICAL APPLICATION 4:Contrasted trajectories in pristine and impacted sandy beaches undergoing green tide events
# Data sets from Quillien, N., Nordström, M.C., Schaal, G., Bonsdorff, E., Grall, J., 2016. 
# Opportunistic basal resource simplifies food web structure and functioning of a highly dynamic marine environment. 
# Journal of Experimental Marine Biology and Ecology 477, 92–102.

#load the data set 1
load(file = "GT1.Rdata")
data<-GT1

#############################################

sites<-c(rep(1:2,4))
surveys<-c(rep("1",2),rep("2",2),rep("3",2),rep("4",2))

coa<-PCA(data, graph = TRUE,ncp=5)

ind <- get_pca_ind(coa)
ind$coord

xy<-matrix(ind$coord, nrow=8,ncol=5)


cbind(sites,surveys,xy)
D=dist(xy)
D

cols=c("blue","green")

#metrics calculations
Net_Changes<-as.data.frame(trajectoryLengths(D,sites,surveys, relativeToInitial=TRUE))
Segment_lengths<-as.data.frame(trajectoryLengths(D,sites,surveys, relativeToInitial = FALSE))

trajectoryLengths(D,sites,surveys,relativeToInitial=TRUE)

xypcoa<-trajectoryPCoA(D, sites, surveys, lwd = 1, traj.colors =cols)
xypcoa<-xypcoa$points[,1:2]

Angl<-trajectoryAngles2D(xypcoa, sites, surveys, betweenSegments = FALSE)

trajectoryDirectionality(D, sites, surveys)

AnglTHETA<-trajectoryAngles(D, sites, surveys, relativeToInitial = FALSE)

#########
#FIGURE7
#########
X11()
trajectoryPCoA(D, sites, surveys, lwd = 1, traj.colors =cols)

x11()
plot(-(ind$coord[,1:2]), col=c("blue", "green"))
x11()
plot(-(ind$coord[,1:2]), col=c("white", "white"))
arrows(c(rep(0,5)),c(rep(0,5)),c(0.4966,-0.3695,0.8446,-0.8477,-0.7029),
       c(-0.8334,-0.8711,0.3640,-0.2179,0.5694),code=2,lwd=0.2, col="black", lt=1, length = 0.1)

#barplots
df<-as.data.frame(t(GT1))
df_del1<-c(0,0,0,0,0)
df_del1<-as.data.frame(df_del1)
df1<-df[,c(1,3,5,7)]
for (i in 1:3){
  df_del1[,i]<--(df1[,i])+(df1[,i+1])}
colnames(df_del1)<-c("S1","S2","S3")
rownames(df_del1)<-rownames(df1)

df_del2<-c(0,0,0,0,0)
df_del2<-as.data.frame(df_del2)
df2<-df[,c(2,4,6,8)]
for (i in 1:3){
  df_del2[,i]<--(df2[,i])+(df2[,i+1])}
colnames(df_del2)<-c("S1","S2","S3")
rownames(df_del2)<-rownames(df2)

ind_shift<-c(df_del1[,1],df_del1[,2],df_del1[,3],df_del2[,1],df_del2[,2],df_del2[,3])
df_del<-as.data.frame(ind_shift)
df_del$segments<-rep(c(rep("S1",5),rep("S2",5),rep("S3",5)),2)
df_del$sites<-c(rep("No_GT",15),rep("GT",15))
df_del$indices<-rownames(df1)

df_delS1<-df_del[df_del$segments %in% "S1",]
df_delS2<-df_del[df_del$segments %in% "S2",]
df_delS3<-df_del[df_del$segments %in% "S3",]

#barplot_S1
X11()
pG<-ggplot(data=df_delS1, aes(x=indices, y=ind_shift, fill=sites)) +
  geom_bar(stat="identity",position=position_dodge())+
  scale_fill_manual(values=c("green","blue"))+
  scale_color_manual(values=c("green","blue"))+
  #scale_x_discrete(limits=ind_shift)+
  theme_minimal()+
  theme(axis.text.x = element_text(size=12),
        axis.text.y = element_text(size=12))
pG
#barplot_S2
X11()
pG<-ggplot(data=df_delS2, aes(x=indices, y=ind_shift, fill=sites)) +
  geom_bar(stat="identity",position=position_dodge())+
  scale_fill_manual(values=c("green","blue"))+
  scale_color_manual(values=c("green","blue"))+
  #scale_x_discrete(limits=cat)+
  theme_minimal()+
  theme(axis.text.x = element_text(size=12),
        axis.text.y = element_text(size=12))
pG

#barplot_S3
X11()
pG<-ggplot(data=df_delS3, aes(x=indices, y=ind_shift, fill=sites)) +
  geom_bar(stat="identity",position=position_dodge())+
  scale_fill_manual(values=c("green","blue"))+
  scale_color_manual(values=c("green","blue"))+
  #scale_x_discrete(limits=ind_shift)+
  theme_minimal()+
  theme(axis.text.x = element_text(size=12),
        axis.text.y = element_text(size=12))
pG


#bar plot shift may to november
df_del1all<--(df1[,1])+(df1[,4])
df_del2all<--(df2[,1])+(df2[,4])
ind_shift<-c(df_del1all,df_del2all)
df_delall<-as.data.frame(ind_shift)
df_delall$sites<-c(rep("No_GT",5),rep("GT",5))
df_delall$indices<-rownames(df1)

X11()
pG<-ggplot(data=df_delall, aes(x=indices, y=ind_shift, fill=sites)) +
  geom_bar(stat="identity",position=position_dodge())+
  scale_fill_manual(values=c("green","blue"))+
  scale_color_manual(values=c("green","blue"))+
  #scale_x_discrete(limits=ind_shift)+
  theme_minimal()+
  theme(axis.text.x = element_text(size=12),
        axis.text.y = element_text(size=12))
pG


#################
#load the data set 2
load(file = "GT2.Rdata")
data<-GT2

#############################################
sites<-data$CTA
surveys<-data$Num_Month

#2D delta space
Net_Changes<-as.data.frame(trajectoryLengths2D(data[,16:17],sites,surveys, relativeToInitial=TRUE)) 
Segment_Length<-as.data.frame(trajectoryLengths2D(data[,16:17],sites,surveys, relativeToInitial=FALSE))
Angles<-trajectoryAngles2D(data[,16:17],sites,surveys,betweenSegments = FALSE)

data$Net_Changes<-c(0,0.54,0.34,0.76,0,4.44,3.66,2.84,0,1.03,1.05,1.74,0,4.80,2.81,3.46,
                       0,0.25,0.85,0.53,0,3.65,2.53,2.23,0,0.72,2.54,0.89)

p<-ggplot(data=data,aes(x=d13C,y=d15N,color=Beach))+
  geom_point(aes(size=Net_Changes))+
  geom_point()+scale_color_manual(values=c("Green","Blue"))+
  geom_path(aes(x=d13C,y=d15N,group=CTA,color=Beach),arrow = arrow(length = unit(0.30, "cm")))+
  geom_text(aes(label=text),hjust=-0.2, vjust=-0.2,size=3, color="Black")+
  xlab(expression(delta^13*"C")) +
  ylab(expression(delta^15*"N"))+
  guides(colour = guide_legend(override.aes = list(size=0.5)))+
  #coord_cartesian(xlim = c(-25.5, -16), ylim = c(4, 12.5))
  facet_wrap(~Species_Source)
X11()  
p+ theme_minimal()

#################################################################################################
#ECOLOGICAL APPLICATION 5: Biological invasions and trophic structure dynamic of lake fish communities

#load the data set

load("Lakes.Rdata")
Garonne<-readOGR("Gar_Ari_7lacs.shp")
#############################################

######SITA
sites<-c(rep("BID",3),rep("BIR",3),rep("BVI",3),rep("LAM1",3),rep("LAV",3),rep("POU",3))
surveys<-c(rep(c("2014","2016","2018"),6))

data<-Lakes
data<-data[,c(5:6,9,12)]
data<-data[-c(1,5,9,13,17,21),]

coa<-PCA(data, graph = TRUE,ncp=4)

ind <- get_pca_ind(coa)
ind$coord


xy<-matrix(ind$coord, nrow=18,ncol=4)


cbind(sites,surveys,xy)
D=dist(xy)
D

#SITA metrics
Net_Changes<-as.data.frame(trajectoryLengths(D,sites,surveys, relativeToInitial = TRUE))
Segment_Length<-as.data.frame(trajectoryLengths(D,sites,surveys, relativeToInitial = FALSE))
DIR<-as.data.frame(trajectoryDirectionality(D, sites, surveys))
AnglTHETA<-trajectoryAngles(D, sites, surveys, relativeToInitial = FALSE)

indcoord<-as.data.frame(ind$coord)
indcoord<-indcoord[,1:2]
indcoord$Lakes<-sites
indcoord$Years<-surveys
indcoord$Net_changes<-c(0,Net_Changes[1,1],Net_Changes[1,2],0,Net_Changes[2,1],Net_Changes[2,2],
                        0,Net_Changes[3,1],Net_Changes[3,2],0,Net_Changes[4,1],Net_Changes[4,2],
                        0,Net_Changes[5,1],Net_Changes[5,2],0,Net_Changes[6,1],Net_Changes[6,2])
##########
#Figure9-A
##########
p<-ggplot(data=indcoord,aes(x=Dim.1,y=Dim.2, color=Lakes))+
  geom_point(aes(size=Net_changes))+
  geom_path(aes(x=Dim.1,y=Dim.2,group=Lakes,color=Lakes),arrow = arrow(length = unit(0.30, "cm")))+
  #geom_text(aes(label=Years),hjust=-0.3, vjust=-0.3,size=2, color="Black")+
  xlab(expression("PCA1 (46.2%)")) +
  ylab(expression("PCA2 (34.1%)"))+
  scale_color_manual(values = c("#440154FF","#414487FF","#2A788EFF",
                                "#22A884FF","#7AD151FF","#FDE725FF"))

X11()  
p+ theme_minimal()+ 
  theme(
    # Masquer les bords des panneaux et supprimer les lignes de grilles
    panel.border = element_blank(),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    axis.line = element_line(colour = "black"))


#DIM1 density
gg_dist_Dim1 = ggplot(indcoord, aes(Dim.1, fill=Lakes)) + geom_density(alpha=.5)+
  scale_fill_manual(values = c("#440154FF","#414487FF","#2A788EFF",
                               "#22A884FF","#7AD151FF","#FDE725FF")) 
gg_dist_Dim1 = gg_dist_Dim1 + theme(axis.title.y=element_blank(),
                                    axis.text=element_blank(),
                                    axis.line=element_blank(),
                                    axis.ticks=element_blank(),
                                    panel.grid.major = element_blank(),
                                    panel.grid.minor = element_blank(),
                                    panel.background =element_blank())
gg_dist_Dim1 = gg_dist_Dim1 + theme(legend.position = "none")+
  scale_x_continuous(limits = c(-2.5, 3.5))+scale_y_continuous(limits = c(0, 5))
x11()
gg_dist_Dim1

#DIM2 density
gg_dist_Dim2 = ggplot(indcoord, aes(Dim.2, fill=Lakes))+
  scale_fill_manual(values = c("#440154FF","#414487FF","#2A788EFF",
                               "#22A884FF","#7AD151FF","#FDE725FF"))+
  geom_density(alpha=.5)+ 
  coord_flip()

gg_dist_Dim2 = gg_dist_Dim2 + theme(axis.title.y=element_blank(),
                                    axis.text=element_blank(),
                                    axis.line=element_blank(),
                                    axis.ticks=element_blank(),
                                    panel.grid.major = element_blank(),
                                    panel.grid.minor = element_blank(),
                                    panel.background =element_blank())
x11()
gg_dist_Dim2+
  scale_x_continuous(limits = c(-3.5, 2.5))+scale_y_continuous(limits = c(0, 5))

distS1<-sum(Segment_Length[,1])
distS2<-sum(Segment_Length[,2])

distLt1<-sum(Net_Changes[,1])
distLt2<-sum(Net_Changes[,2])
diffLt<-Net_Changes[,2]-Net_Changes[,1]


#####################################################
##########
#Figure9-B
##########
#shift 2014 to 2018
df_del<-data[-c(2,5,8,11,14,17),]

del_rangeC<-c()
for (i in c(2,4,6,8,10,12)){
  del_rangeC[(i-i/2)]<--df_del[i-1,1]+df_del[i,1]  
}
del_rangeC<-unlist(del_rangeC)

del_rangeN<-c()
for (i in c(2,4,6,8,10,12)){
  del_rangeN[(i-i/2)]<--df_del[i-1,2]+df_del[i,2]  
}
del_rangeN<-unlist(del_rangeN)

del_IRic<-c()
for (i in c(2,4,6,8,10,12)){
  del_IRic[(i-i/2)]<--df_del[i-1,3]+df_del[i,3]  
}
del_IRic<-unlist(del_IRic)

del_IEve<-c()
for (i in c(2,4,6,8,10,12)){
  del_IEve[(i-i/2)]<--df_del[i-1,4]+df_del[i,4]  
}
del_IEve<-unlist(del_IEve)

del_14_18<-as.data.frame(cbind(del_rangeC,del_rangeN,del_IRic,del_IEve))
colnames(del_14_18)<-c("Range d13C","Range d15N","IRic","IEve")
del_14_18$Lakes<-c("BIDOT","BIRAZEL","BOIS-VIEUX","LAMARTINE","LAVERNOSE","POUVIL")
del_14_18<-as.data.frame(melt(del_14_18,id=c("Lakes")))
colnames(del_14_18)<-c("Lakes","Indices","Shift")



pG1<-ggplot(data=del_14_18[1:6,], aes(x=Indices, y=Shift, fill=Lakes)) +
  geom_bar(stat="identity",position=position_dodge())+
  scale_fill_manual(values=c("#440154FF","#414487FF","#2A788EFF",
                             "#22A884FF","#7AD151FF","#FDE725FF"))+
  scale_color_manual(values=c("#440154FF","#414487FF","#2A788EFF",
                              "#22A884FF","#7AD151FF","#FDE725FF"))+
  #scale_x_discrete(limits=ind_shift)+
  theme_minimal()+
  theme(axis.text.x = element_text(size=12),
        axis.text.y = element_text(size=12))
X11()
pG1

pG2<-ggplot(data=del_14_18[7:12,], aes(x=Indices, y=Shift, fill=Lakes)) +
  geom_bar(stat="identity",position=position_dodge())+
  scale_fill_manual(values=c("#440154FF","#414487FF","#2A788EFF",
                             "#22A884FF","#7AD151FF","#FDE725FF"))+
  scale_color_manual(values=c("#440154FF","#414487FF","#2A788EFF",
                              "#22A884FF","#7AD151FF","#FDE725FF"))+
  #scale_x_discrete(limits=ind_shift)+
  theme_minimal()+
  theme(axis.text.x = element_text(size=12),
        axis.text.y = element_text(size=12))
X11()
pG2

pG3<-ggplot(data=del_14_18[13:18,], aes(x=Indices, y=Shift, fill=Lakes)) +
  geom_bar(stat="identity",position=position_dodge())+
  scale_fill_manual(values=c("#440154FF","#414487FF","#2A788EFF",
                             "#22A884FF","#7AD151FF","#FDE725FF"))+
  scale_color_manual(values=c("#440154FF","#414487FF","#2A788EFF",
                              "#22A884FF","#7AD151FF","#FDE725FF"))+
  #scale_x_discrete(limits=ind_shift)+
  theme_minimal()+
  theme(axis.text.x = element_text(size=12),
        axis.text.y = element_text(size=12))
X11()
pG3

pG4<-ggplot(data=del_14_18[19:24,], aes(x=Indices, y=Shift, fill=Lakes)) +
  geom_bar(stat="identity",position=position_dodge())+
  scale_fill_manual(values=c("#440154FF","#414487FF","#2A788EFF",
                             "#22A884FF","#7AD151FF","#FDE725FF"))+
  scale_color_manual(values=c("#440154FF","#414487FF","#2A788EFF",
                              "#22A884FF","#7AD151FF","#FDE725FF"))+
  #scale_x_discrete(limits=ind_shift)+
  theme_minimal()+
  theme(axis.text.x = element_text(size=12),
        axis.text.y = element_text(size=12))
X11()
pG4

X11()
p<-grid.arrange(pG1,pG2,pG3,pG4, ncol=2) 

##########
#Figure9-C
##########
station<-c("BID","BIR","BVI","LAM1","LAV","POU")
station<-as.data.frame(station)
station$X<-c(561352.139,561708.837,566919.895,565498.659,559427.429,558790.742)
station$Y<-c(6271116.041,6271637.038,6270289.291,6268880.842,6255684.189,6254090.025)
colnames(station)<-c("Id","X","Y")

#CARTE 3 états
##############
dist14_18<-c(Net_Changes[,2])
dist14_16<-c(Segment_Length[,1])
dist16_18<-c(Segment_Length[,2])
dist<-as.data.frame(cbind(station$Id,dist14_16,dist16_18,dist14_18))

#Calcul OCT pour déterminer si dist 01_19 s'oppose ou se cumul à dist 87_01
diffcdt=dist14_16-dist14_18
#CDT
CDT<-c()
for (i in 1:6){
  if (diffcdt[[i]]>0) {
    CDT[i] =1
  } else {
    CDT[i]  =2
  }}

dist$CDT<-CDT

distCIS<-dist[dist$CDT %in% c(1),]
distDIS<-dist[dist$CDT %in% c(2),]

#coordonnées d'affichage des triangles
station_upY<-c(station$Y+500)
station_dwnY<-c(station$Y-500)

col<-c("black","grey")
cex<-c(0.8,0.8)
pch<-c(24,24)
pch2<-c(25,24)
text_leg<-c("recovering",  "departing")
text_leg2<-c("14_18 changes")

x11()
plot(station$X,station$Y,col = "green",pch = 1 ,cex=dist14_18/1.2,xlim=c(min(551000),max(571000)),
     ylim=c(min(6253000),max(6272000)),xlab="Longitude",ylab="Latitude", main="Trophic changes (2014,2016,2018)")
plot(Garonne,add=T, col="blue")
#text(station$X,station$Y,c("BIDOT","BIRAZEL","BOIS-VIEUX","LAMARTINE","LAVERNOSE","POUVIL"))
points(station$X,station_dwnY,bg=col[CDT],col =col[CDT] ,
       pch = pch ,cex=dist14_16/1.2,xlim=c(min(551000),max(571000)),
       ylim=c(min(6253000),max(6272000)))
points(station$X,station_upY,bg=col[CDT],col = col[CDT],
       pch = pch2[CDT] ,cex=dist16_18/1.2,xlim=c(min(551000),max(571000)),
       ylim=c(min(6253000),max(6272000)))
points(station$X,station$Y,col = "green",pch = 1 ,cex=dist14_18/1.2,xlim=c(min(551000),max(571000)),
       ylim=c(min(6253000),max(6272000)))


#################################################################################################
#ECOLOGICAL APPLICATION 6: Spatio-temporal variability of δ13C and δ15N modelled isoscapes in the Northeast Pacific
# Data sets from: Espinasse, B., Hunt, B.P.V., Batten, S.D., Pakhomov, E.A., 2020. 
# Defining isoscapes in the Northeast Pacific as an index of ocean productivity. 
# Global Ecol Biogeogr 29, 246–261.


###################
#############
#FIGURE10-1/2
#############
#load the data set
load("Isoscape_Pacific2013_15.Rdata")
df<-Isoscape_Pacific2013_15
#SITA metrics
sites<-df$station
surveys<-df$Year
Angl<-trajectoryAngles2D(df[,3:4],sites,surveys, betweenSegments = FALSE)
Length<-trajectoryLengths2D(df[,3:4],sites,surveys)
data<-as.data.frame(cbind(df[1:489,],Angl,Length[,1]))
colnames(data)<-c("Latitude","Longitude","d13C","d15N","Stations","Years","Angles","Lengths")

#Angle transformation
angle<-data$Angles
Angles2<-c()
for (i in 1:length(angle)) {
  Angles2[i] <- c(ifelse(angle[i]==0,(angle[i]-270)*pi/180,
                         ifelse(angle[i]==180,(angle[i]-270)*pi/180,
                                ifelse(angle[i]==90,(angle[i]+270)*pi/180,
                                       ifelse(angle[i]==270,(angle[i]+270)*pi/180,
                                              ifelse(angle[i]==360,(angle[i]-270)*pi/180,  
                                                     ifelse(angle[i]>0 & angle[i]<90 ,(90-angle[i])*pi/180,
                                                            ifelse(angle[i]>90 & angle[i]<180 ,(90-angle[i])*pi/180,
                                                                   ifelse(angle[i]>180 & angle[i]<270,(180+(270-angle[i]))*pi/180,
                                                                          ifelse(angle[i]>270 & angle[i]<360,(90+(360-angle[i]))*pi/180,"ERROR"))))))))))
}

data$Angles2<-Angles2

p<-ggplot(data, 
          aes(x = Longitude, 
              y = Latitude, 
              fill = Lengths, 
              angle = Angles2, 
              radius = scales::rescale(Lengths, c(0.3, 1)))) +
  geom_raster(interpolate = TRUE) +
  geom_spoke(arrow = arrow(length = unit(.07, 'inches'))) + 
  scale_fill_distiller(palette = "RdYlBu") + 
  coord_equal(expand = 0) + 
  theme(legend.position = 'bottom', 
        legend.direction = 'horizontal',
        panel.background = element_rect(fill = "white"))


X11()
p


#############
#FIGURE10-2/2
#############
#load the data set
load("Isoscape_Pacific2015_17.Rdata")
df<-Isoscape_Pacific2015_17
#SITA metrics
sites<-df$station
surveys<-df$Year
Angl<-trajectoryAngles2D(df[,3:4],sites,surveys, betweenSegments = FALSE)
Length<-trajectoryLengths2D(df[,3:4],sites,surveys)
data<-as.data.frame(cbind(df[1:488,],Angl,Length[,1]))
colnames(data)<-c("Latitude","Longitude","d13C","d15N","Stations","Years","Angles","Lengths")

#Angle transformation
angle<-data$Angles
Angles2<-c()
for (i in 1:length(angle)) {
  Angles2[i] <- c(ifelse(angle[i]==0,(angle[i]-270)*pi/180,
                         ifelse(angle[i]==180,(angle[i]-270)*pi/180,
                                ifelse(angle[i]==90,(angle[i]+270)*pi/180,
                                       ifelse(angle[i]==270,(angle[i]+270)*pi/180,
                                              ifelse(angle[i]==360,(angle[i]-270)*pi/180,  
                                                     ifelse(angle[i]>0 & angle[i]<90 ,(90-angle[i])*pi/180,
                                                            ifelse(angle[i]>90 & angle[i]<180 ,(90-angle[i])*pi/180,
                                                                   ifelse(angle[i]>180 & angle[i]<270,(180+(270-angle[i]))*pi/180,
                                                                          ifelse(angle[i]>270 & angle[i]<360,(90+(360-angle[i]))*pi/180,"ERROR"))))))))))
}

data$Angles2<-Angles2


p<-ggplot(data, 
          aes(x = Longitude, 
              y = Latitude, 
              fill = Lengths, 
              angle = Angles2, 
              radius = scales::rescale(Lengths, c(0.3, 1)))) +
  geom_raster(interpolate = TRUE) +
  geom_spoke(arrow = arrow(length = unit(.07, 'inches'))) + 
  scale_fill_distiller(palette = "RdYlBu") + 
  coord_equal(expand = 0) + 
  theme(legend.position = 'bottom', 
        legend.direction = 'horizontal',
        panel.background = element_rect(fill = "white"))
X11()
p


#############
#FIGURE11
#############
#load the data set
load("datasuperheatmap.rdata")

#direction range
deg <- 15

dir.breaks <- c(0,15,30,45,60,75,90,105,120,135,150,165,180,195,210,225,240,255,270,285,300,315,330,345,360)


dir.binned <- cut(data$Angles,
                  breaks = dir.breaks,
                  ordered_result = TRUE)

# bar labels
dir.labels <- as.character(c(seq(0, 360-deg, by = deg),0))

levels(dir.binned) <- dir.labels

data$dir.binned <- dir.binned

data<-data[,c(6,7,8,10)]

#direction vs SI patterns
data<-data[order(data$dir.binned, decreasing=FALSE),]
rownames(data)<-1:9206
data$ISpattern<- c(rep("+d13C/+d15N",2862),rep("+d13C/-d15N",1840),rep("-d13C/-d15N",2931), rep("-d13C/+d15N",1573))

data1<-as.data.frame(table(data$dir.binned,data$Years))

data2<-aggregate(x = data$Lengths, by = list(data$dir.binned, data$Years), FUN=sum, drop=FALSE)
data2[is.na(data2)] <- 0 


data1$Lengths<-data2$x
dfa<-data1
colnames(dfa)<-c("Directions","Periods","Nb_stations","Lengths")

#dfb<-as.data.frame(cbind(dfa[1:24,3],dfa[25:48,3]))
#rownames(dfb)<-dfa[1:24,1]
#colnames(dfb)<-c("2013-2015","2015-2017")
#dfb$Directions<-rownames(dfb)


#https://www.r-graph-gallery.com/79-levelplot-with-ggplot2.html

library(ggplot2)
library(hrbrthemes)
library(viridis)




#https://rstudio-pubs-static.s3.amazonaws.com/215319_ac67755c296b441dac7b24b48fc30156.html

#heat map
p<-ggplot(dfa, aes(Periods, Directions, fill= Nb_stations)) + 
  geom_tile() +
  scale_fill_viridis(discrete=FALSE) +
  theme_minimal()+
  theme(axis.text.x = element_text(size=10, angle=90))
x11()
p
#extraction legend heat map
tmp <- ggplot_gtable(ggplot_build(p))
leg <- which(sapply(tmp$grobs, function(x) x$name) == "guide-box")
legend_heat <- tmp$grobs[[leg]]

#heat map no legend
p.clean <- p +
  theme(legend.position="none")
p.clean
x11()
p.clean

#X bar plot
df.Xbarplot<-aggregate(dfa$Lengths, by = list(dfa$Periods), FUN = sum)
colnames(df.Xbarplot)<-c("Periods","Lengths")
bp.x <- ggplot(data = df.Xbarplot, aes(x = factor(Periods), y = Lengths)) + 
  geom_bar(stat = "identity", aes(fill = Lengths)) + theme_minimal() +
  theme(axis.text.x = element_text(size = 10,angle=90), 
        axis.title.x = element_text(size = 20, margin = margin(10,0,0,0))) +
  labs(x = "Periods")

x11()
bp.x

tmp <- ggplot_gtable(ggplot_build(bp.x))
leg <- which(sapply(tmp$grobs, function(x) x$name) == "guide-box")
legend_bp.x <- tmp$grobs[[leg]]


bp.x.clean <- bp.x +
  theme(axis.title.y = element_blank(), axis.text.y = element_blank(), 
        axis.ticks.y = element_blank(), axis.text.x = element_blank(), 
        axis.title.x = element_blank())

x11()
bp.x.clean

#Y bar plot
df.Ybarplot<-aggregate(dfa$Lengths, by = list(dfa$Directions), FUN = sum)
colnames(df.Ybarplot)<-c("Directions","Lengths")
df.Ybarplot$ISpattern<- c(rep("+d13C/+d15N",6),rep("+d13C/-d15N",6),rep("-d13C/-d15N",6), rep("-d13C/+d15N",6))


bp.y <- ggplot(data = df.Ybarplot, aes(x = factor(Directions), y = Lengths,fill = ISpattern)) + 
  geom_bar(stat="identity") + theme_minimal() + coord_flip()

x11()
bp.y

bp.y.clean <- bp.y +
  theme(axis.title.y = element_blank(), axis.text.y = element_blank())

x11()
bp.y.clean




